"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import { Button } from "@/components/ui/button";
import Cookies from "js-cookie";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
  DialogTitle,
} from "@/components/ui/dialog";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { FcGoogle } from "react-icons/fc";
import { FaApple } from "react-icons/fa";
export function AuthModal({ isOpen, setIsOpen }) {
  const [isLogin, setIsLogin] = useState(true);
  const [formData, setFormData] = useState({
    user_email: "",
    user_password: "",
    user_name: "",
    confirm_password: "",
  });
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);
  const [fieldErrors, setFieldErrors] = useState({});
  const router = useRouter();

  const handleInputChange = (e) => {
    setFormData({ ...formData, [e.target.id]: e.target.value });
    setFieldErrors({ ...fieldErrors, [e.target.id]: "" });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setLoading(true);
    setError(null);
    setFieldErrors({});

    // Validate password confirmation
    if (!isLogin && formData.user_password !== formData.confirm_password) {
      setFieldErrors({ confirm_password: ["Passwords do not match."] });
      setLoading(false);
      return;
    }

    const apiUrl = isLogin
      ? `${process.env.NEXT_PUBLIC_BASE_URL}login`
      : `${process.env.NEXT_PUBLIC_BASE_URL}register`;
    const requestBody = isLogin
      ? {
          user_email: formData.user_email,
          user_password: formData.user_password,
        }
      : {
          user_email: formData.user_email,
          user_password: formData.user_password,
          user_name: formData.user_name,
          user_role: "customer",
        };

    try {
      const response = await fetch(apiUrl, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify(requestBody),
      });

      const data = await response.json();
      console.log("API Response:", data);

      if (data.success) {
        if (!isLogin) {
          // After successful registration, call login API
          const loginResponse = await fetch(
            `${process.env.NEXT_PUBLIC_BASE_URL}login`,
            {
              method: "POST",
              headers: { "Content-Type": "application/json" },
              body: JSON.stringify({
                user_email: formData.user_email,
                user_password: formData.user_password,
              }),
            }
          );

          const loginData = await loginResponse.json();
          console.log("Login API Response:", loginData);

          if (loginData.success) {
            // Store authentication data from login response
            Cookies.set("access_token", loginData.access_token, {
              expires: 7,
              secure: true,
              sameSite: "Strict",
            });
            Cookies.set("user_id", loginData.user.user_id, {
              expires: 7,
              secure: true,
              sameSite: "Strict",
            });
            Cookies.set("user", JSON.stringify(loginData.user), {
              expires: 7,
              secure: true,
              sameSite: "Strict",
            });
          } else {
            // Handle login failure after successful registration
            setError(
              loginData.message || "Failed to log in after registration."
            );
            setLoading(false);
            return;
          }
        } else {
          // For login, store authentication data directly
          Cookies.set("access_token", data.access_token, {
            expires: 7,
            secure: true,
            sameSite: "Strict",
          });
          Cookies.set("user_id", data.user.user_id, {
            expires: 7,
            secure: true,
            sameSite: "Strict",
          });
          Cookies.set("user", JSON.stringify(data.user), {
            expires: 7,
            secure: true,
            sameSite: "Strict",
          });
        }

        setIsOpen(false);
        setFormData({
          user_email: "",
          user_password: "",
          user_name: "",
          confirm_password: "",
        });

        // Redirect to dashboard
        window.location.reload();
      } else {
        if (data.errors) {
          setFieldErrors(data.errors);
        } else if (data.message) {
          if (data.message === "Email already exists") {
            setFieldErrors({ user_email: [data.message] });
          } else if (data.message.toLowerCase().includes("password")) {
            setFieldErrors({ user_password: [data.message] });
          } else {
            setError(data.message);
          }
        } else {
          setError("Something went wrong. Please try again.");
        }
      }
    } catch (err) {
      console.error("Fetch Error:", err);
      setError("Network error. Please try again.");
    }
    setLoading(false);
  };

  return (
    <Dialog open={isOpen} onOpenChange={setIsOpen}>
      <DialogContent className="sm:max-w-[500px] p-6 mx-auto rounded-lg">
        <DialogHeader className="text-center">
          <DialogTitle className="text-2xl font-bold">
            {isLogin ? "Log In" : "Sign Up"}
          </DialogTitle>
          <DialogDescription className="text-gray-500">
            Fill in your details below to {isLogin ? "Log In" : "Sign Up"}.
          </DialogDescription>
        </DialogHeader>
        {error && <p className="text-red-500 text-center">{error}</p>}
        <form onSubmit={handleSubmit} className="space-y-4">
          {!isLogin && (
            <div>
              <Label htmlFor="user_name">Full Name</Label>
              <Input
                id="user_name"
                placeholder="Full Name"
                value={formData.user_name}
                onChange={handleInputChange}
                required={!isLogin}
                className={`mt-1 ${
                  fieldErrors.user_name ? "border-red-500" : ""
                }`}
              />
              {fieldErrors.user_name && (
                <p className="text-red-500 text-sm">
                  {fieldErrors.user_name[0]}
                </p>
              )}
            </div>
          )}
          <div>
            <Label htmlFor="user_email">Email</Label>
            <Input
              id="user_email"
              placeholder="Email"
              value={formData.user_email}
              onChange={handleInputChange}
              required
              className={`mt-1 ${
                fieldErrors.user_email ? "border-red-500" : ""
              }`}
            />
            {fieldErrors.user_email && (
              <p className="text-red-500 text-sm">
                {fieldErrors.user_email[0]}
              </p>
            )}
          </div>
          <div>
            <Label htmlFor="user_password">Password</Label>
            <Input
              id="user_password"
              type="password"
              placeholder="Password"
              value={formData.user_password}
              onChange={handleInputChange}
              required
              className={`mt-1 ${
                fieldErrors.user_password ? "border-red-500" : ""
              }`}
            />
            {fieldErrors.user_password && (
              <p className="text-red-500 text-sm">
                {fieldErrors.user_password[0]}
              </p>
            )}
          </div>
          {!isLogin && (
            <div>
              <Label htmlFor="confirm_password">Confirm Password</Label>
              <Input
                id="confirm_password"
                type="password"
                placeholder="Confirm Password"
                value={formData.confirm_password}
                onChange={handleInputChange}
                required={!isLogin}
                className={`mt-1 ${
                  fieldErrors.confirm_password ? "border-red-500" : ""
                }`}
              />
              {fieldErrors.confirm_password && (
                <p className="text-red-500 text-sm">
                  {fieldErrors.confirm_password[0]}
                </p>
              )}
            </div>
          )}
          <Button
            type="submit"
            className="w-full bg-blue-600 hover:bg-blue-700 text-white"
            disabled={loading}
          >
            {loading ? "Loading..." : isLogin ? "Log In" : "Create Account"}
          </Button>
        </form>
        <p className="text-center text-sm text-gray-500">
          {isLogin ? "Don’t have an account? " : "Already have an account? "}
          <span
            className="text-blue-500 cursor-pointer"
            onClick={() => {
              setIsLogin(!isLogin);
              setError(null);
              setFieldErrors({});
              setFormData({
                user_email: "",
                user_password: "",
                user_name: "",
                confirm_password: "",
              });
            }}
          >
            {isLogin ? "Sign Up" : "Log In"}
          </span>
        </p>

        <p className="text-center text-sm text-gray-500">
          Or {isLogin ? "log in" : "sign up"} with
        </p>
        <div className="flex justify-center gap-4">
          <button className="p-2 border rounded-full">
            <FcGoogle size={24} />
          </button>
          <button className="p-2 border rounded-full">
            <FaApple size={24} />
          </button>
        </div>
      </DialogContent>
    </Dialog>
  );
}
